<?php
/**
 * The loop that displays posts.
 *
 * The loop displays the posts and the post content. See
 * http://codex.wordpress.org/The_Loop to understand it and
 * http://codex.wordpress.org/Template_Tags to understand
 * the tags used in it.
 *
 * This can be overridden in child themes with loop.php or
 * loop-template.php, where 'template' is the loop context
 * requested by a template. For example, loop-index.php would
 * be used if it exists and we ask for the loop with:
 * <code>get_template_part( 'loop', 'index' );</code>
 *
 * @package WordPress
 * @subpackage DSK
 * @since DSK 1.0
 */
?>

<?php /* Display navigation to next/previous pages when applicable */ ?>
<?php if ( $wp_query->max_num_pages > 1 ) : ?>
	<div id="nav-above" class="navigation">
		<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'dsk' ) ); ?></div>
		<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'dsk' ) ); ?></div>
	</div><!-- #nav-above -->
<?php endif; ?>

<?php /* If there are no posts to display, such as an empty archive page */ ?>
<?php if ( ! have_posts() ) : ?>
	<div id="post-0" class="post error404 not-found">
		<h1 class="entry-title"><?php _e( 'Not Found', 'dsk' ); ?></h1>
		<div class="entry-content">
			<p><?php _e( 'Apologies, but no results were found for the requested archive. Perhaps searching will help find a related post.', 'dsk' ); ?></p>
			<?php get_search_form(); ?>
		</div><!-- .entry-content -->
	</div><!-- #post-0 -->
<?php endif; ?>

<?php
	/* Start the Loop.
	 *
	 * In DSK we use the same loop in multiple contexts.
	 * It is broken into three main parts: when we're displaying
	 * posts that are in the gallery category, when we're displaying
	 * posts in the asides category, and finally all other posts.
	 *
	 * Additionally, we sometimes check for whether we are on an
	 * archive page, a search page, etc., allowing for small differences
	 * in the loop on each template without actually duplicating
	 * the rest of the loop that is shared.
	 *
	 * Without further ado, the loop:
	 */ ?>
<?php while ( have_posts() ) : the_post(); ?>

<?php /* How to display posts of the Gallery format. The gallery category is the old way. */ ?>

	<?php if ( ( function_exists( 'get_post_format' ) && 'gallery' == get_post_format( $post->ID ) ) || in_category( _x( 'gallery', 'gallery category slug', 'dsk' ) ) ) : ?>
		<article <?php post_class('single-post-item'); ?>>
    <div class="post-item-inner">
        <div class="post-thumb">
            <a href="<?php the_permalink(); ?>" class="" title="<?php the_title(); ?>"><span class="imgsc" style="background-image: url('<?php the_post_thumbnail_url('full');?>');"></span></a>
        </div>
        <div class="post-info">
            <div class="post-meta clearfix">
                <div class="date"> <a href="<?php the_permalink(); ?>"><?php the_time('F j, Y'); ?></a></div>
                <ul class="info-meta">
                    <li class="post-author"> <span>By </span> <strong><?php the_author_meta('display_name', $author_id); ?></strong></li>
                    <li class="comment"> <i class="far fa-comment"></i> <?php comments_number( '0', '1', '%' ); ?></li>
                </ul>
            </div>
            <h2 class="post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
            <div class="post-content"><?php the_excerpt(); ?></div> <a href="<?php the_permalink(); ?>" class="dskbtn"> Read more</a></div>
    </div>
</article><!-- #post-## -->

<?php /* How to display posts of the Aside format. The asides category is the old way. */ ?>

	<?php elseif ( ( function_exists( 'get_post_format' ) && 'aside' == get_post_format( $post->ID ) ) || in_category( _x( 'asides', 'asides category slug', 'dsk' ) )  ) : ?>
		<article <?php post_class('single-post-item'); ?>>
    <div class="post-item-inner">
        <div class="post-thumb">
            <a href="<?php the_permalink(); ?>" class="" title="<?php the_title(); ?>"><span class="imgsc" style="background-image: url('<?php the_post_thumbnail_url('full');?>');"></span></a>
        </div>
        <div class="post-info">
            <div class="post-meta clearfix">
                <div class="date"> <a href="<?php the_permalink(); ?>"><?php the_time('F j, Y'); ?></a></div>
                <ul class="info-meta">
                    <li class="post-author"> <span>By </span> <strong><?php the_author_meta('display_name', $author_id); ?></strong></li>
                    <li class="comment"> <i class="far fa-comment"></i> <?php comments_number( '0', '1', '%' ); ?></li>
                </ul>
            </div>
            <h2 class="post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
            <div class="post-content"><?php the_excerpt(); ?></div> <a href="<?php the_permalink(); ?>" class="dskbtn"> Read more</a></div>
    </div>
</article><!-- #post-## -->

<?php /* How to display all other posts. */ ?>

	<?php else : ?>
		<article <?php post_class('single-post-item'); ?>>
    <div class="post-item-inner">
        <div class="post-thumb">
            <a href="<?php the_permalink(); ?>" class="" title="<?php the_title(); ?>"><span class="imgsc" style="background-image: url('<?php the_post_thumbnail_url('full');?>');"></span></a>
        </div>
        <div class="post-info">
            <div class="post-meta clearfix">
                <div class="date"> <a href="<?php the_permalink(); ?>"><?php the_time('F j, Y'); ?></a></div>
                <ul class="info-meta">
                    <li class="post-author"> <span>By </span> <strong><?php the_author_meta('display_name', $author_id); ?></strong></li>
                    <li class="comment"> <i class="far fa-comment"></i> <?php comments_number( '0', '1', '%' ); ?></li>
                </ul>
            </div>
            <h2 class="post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
            <div class="post-content"><?php the_excerpt(); ?></div> <a href="<?php the_permalink(); ?>" class="dskbtn"> Read more</a></div>
    </div>
</article><!-- #post-## -->

		<?php comments_template( '', true ); ?>

	<?php endif; // This was the if statement that broke the loop into three parts based on categories. ?>

<?php endwhile; // End the loop. Whew. ?>

<?php /* Display navigation to next/previous pages when applicable */ ?>
<?php if (  $wp_query->max_num_pages > 1 ) : ?>
	<div id="nav-below" class="navigation">
		<?php wp_pagenavi(); ?>
	</div><!-- #nav-below -->
<?php endif; ?>
